@@ -38,6 +38,14 @@ if TYPE_CHECKING:
     from django.db.models import QuerySet
 
 
+class classproperty(object):
+    def __init__(self, f):
+        self.f = f
+
+    def __get__(self, obj, owner):
+        return self.f(owner)
+
+
 def serializer_field_to_gql_field(serializer_field: Type[SerializerField], **kwargs):
     nullable = None
     if isinstance(
@@ -55,20 +63,26 @@ def serializer_field_to_gql_field(serializer_field: Type[SerializerField], **kwa
 
 class Schema:
     _types = {}  # type: Dict[str, ModelSerializerType]
-    schema = None  # type: GraphQLSchema
+    _schema = None  # type: GraphQLSchema
     objecttype_registry = {}  # type: Dict[Type[Model], GraphQLObjectType]
     modelserializer_registry = {}  # type: Dict[Type[Model], ModelSerializer]
 
     def __init_subclass__(cls):
         # See what fields were added and add those to our schema
-        Schema._types.update(
+        cls._types.update(
             {
                 k: v
                 for k, v in cls.__dict__.items()
                 if not k.startswith("_") and isinstance(v, ModelSerializerType)
             }
         )
-        Schema._update_schema()
+        # cls._update_schema()
+
+    @classproperty
+    def schema(cls):
+        if cls._schema is None:
+            cls._update_schema()
+        return cls._schema
 
     @classmethod
     def register_type(cls, type_: "ModelSerializerType"):
@@ -329,7 +343,28 @@ class Schema:
                 resolve=resolve_update,
             )
 
-        Schema.schema = GraphQLSchema(query, mutation)
+            # Delete mutation
+            if type_.delete_mutation:
+
+                def resolve_delete(root, info, type_=type_, **kwargs):
+                    pk = kwargs[type_.model._meta.pk.name]
+                    instance = type_.queryset.get(pk=pk)
+                    instance.delete()
+                    return instance
+
+                # TODO: Tasks pending completion -@flyte at 26/08/2020, 10:46:55
+                # Remove hardcoded Int for primary key and work out the right field type
+                mutation.fields[f"delete_{toplevel_field_name}"] = GraphQLField(
+                    cls.objecttype_registry[type_.model],
+                    args={
+                        type_.model._meta.pk.name: GraphQLArgument(
+                            GraphQLNonNull(GraphQLInt)
+                        )
+                    },
+                    resolve=resolve_delete,
+                )
+
+        cls._schema = GraphQLSchema(query, mutation)
 
 
 class ModelSerializerType:
@@ -352,8 +387,9 @@ class ModelSerializerType:
         field: str = "",
         list_field: str = None,
         queryset: QuerySet = None,
-        create_mutation: bool = False,
-        update_mutation: bool = False,
+        create_mutation: bool = True,
+        update_mutation: bool = True,
+        delete_mutation: bool = True,
     ):
         self.name = name or self.__class__.__name__
         self.singular_lookup_fields = singular_lookup_fields
@@ -363,4 +399,5 @@ class ModelSerializerType:
         self.queryset = queryset if queryset is not None else self.model.objects.all()
         self.create_mutation = create_mutation
         self.update_mutation = update_mutation
+        self.delete_mutation = delete_mutation
         Schema.register_type(self)
